diff -r 3ea58ea786b2 code/nel/CMakeLists.txt
--- a/code/nel/CMakeLists.txt	Fri May 07 12:53:54 2010 +0200
+++ b/code/nel/CMakeLists.txt	Fri May 07 15:50:56 2010 -0700
@@ -72,6 +72,7 @@
 FIND_PACKAGE(LibXml2 REQUIRED)
 FIND_PACKAGE(PNG REQUIRED)
 FIND_PACKAGE(Jpeg)
+FIND_PACKAGE(Xf86VidMode)
 
 NL_SETUP_BUILD()
 
diff -r 3ea58ea786b2 code/nel/CMakeModules/FindXf86VidMode.cmake
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/code/nel/CMakeModules/FindXf86VidMode.cmake	Fri May 07 15:50:56 2010 -0700
@@ -0,0 +1,45 @@
+# - Locate Jpeg library
+# This module defines
+#  XF86VidMode_LIBRARY, the library to link against
+#  XF86VidMode_FOUND, if false, do not try to link to XF86VidMode
+#  XF86VidMode_INCLUDE_DIR, where to find headers.
+
+IF(XF86VidMode_LIBRARY AND XF86VidMode_INCLUDE_DIR)
+  # in cache already
+  SET(XF86VidMode_FIND_QUIETLY TRUE)
+ENDIF(XF86VidMode_LIBRARY AND XF86VidMode_INCLUDE_DIR)
+
+
+FIND_PATH(XF86VidMode_INCLUDE_DIR
+  xf86vm.h
+  PATHS
+  $ENV{XF86VidMode_DIR}/include
+  /usr/include/X11/
+  /usr/X11R6/include/
+  PATH_SUFFIXES extensions 
+)
+
+FIND_LIBRARY(XF86VidMode_LIBRARY
+  Xxf86vm 
+  PATHS
+  $ENV{XF86VidMode_DIR}/lib
+  /usr/X11R6/lib
+  /usr/lib
+  /sw/lib
+  /opt/local/lib
+  /opt/csw/lib
+  /opt/lib
+  /usr/freeware/lib64
+)
+
+IF(XF86VidMode_LIBRARY AND XF86VidMode_INCLUDE_DIR)
+  SET(XF86VidMode_FOUND "YES")
+  ADD_DEFINITIONS(-DXF86VIDMODE)
+  IF(NOT XF86VidMode_FIND_QUIETLY)
+    MESSAGE(STATUS "Found XF86VidMode: ${XF86VidMode_LIBRARY}")
+  ENDIF(NOT XF86VidMode_FIND_QUIETLY)
+ELSE(XF86VidMode_LIBRARY AND XF86VidMode_INCLUDE_DIR)
+  IF(NOT XF86VidMode_FIND_QUIETLY)
+    MESSAGE(STATUS "Warning: Unable to find XF86VidMode!")
+  ENDIF(NOT XF86VidMode_FIND_QUIETLY)
+ENDIF(XF86VidMode_LIBRARY AND XF86VidMode_INCLUDE_DIR)
diff -r 3ea58ea786b2 code/nel/src/3d/driver/opengl/CMakeLists.txt
--- a/code/nel/src/3d/driver/opengl/CMakeLists.txt	Fri May 07 12:53:54 2010 +0200
+++ b/code/nel/src/3d/driver/opengl/CMakeLists.txt	Fri May 07 15:50:56 2010 -0700
@@ -9,7 +9,7 @@
 ADD_LIBRARY(${NLDRV_OGL_LIB} SHARED ${SRC})
 
 INCLUDE_DIRECTORIES(${LIBXML2_INCLUDE_DIR} ${OPENGL_INCLUDE_DIR})
-TARGET_LINK_LIBRARIES(${NLDRV_OGL_LIB} nel3d nelmisc ${OPENGL_LIBRARIES})
+TARGET_LINK_LIBRARIES(${NLDRV_OGL_LIB} nel3d nelmisc ${OPENGL_LIBRARIES} ${XF86VidMode_LIBRARY})
 SET_TARGET_PROPERTIES(${NLDRV_OGL_LIB} PROPERTIES 
   VERSION ${NL_VERSION}
   PROJECT_LABEL "Driver, Video: OpenGL")
@@ -31,4 +31,4 @@
 INSTALL(TARGETS ${NLDRV_OGL_LIB} LIBRARY DESTINATION lib RUNTIME DESTINATION bin COMPONENT drivers3d)
 IF(WITH_MAXPLUGIN)
   INSTALL(TARGETS ${NLDRV_OGL_LIB} RUNTIME DESTINATION maxplugin COMPONENT drivers3d)
-ENDIF(WITH_MAXPLUGIN)
\ No newline at end of file
+ENDIF(WITH_MAXPLUGIN)
